pub struct EagerOpRef<T, E> { /* private fields */ }Expand description
Eager operation reference for local/synchronous operations.
This is a simple wrapper for synchronous operations that complete immediately.
The result is stored and returned on first call to finish(). Subsequent calls
will return a clone of the original error (if the operation failed) or an
AlreadyFinished error (if the operation succeeded).
Implementations