EagerOpRef

Struct EagerOpRef 

pub struct EagerOpRef<T, E> { /* private fields */ }
Eager operation reference for local/synchronous operations.

This is a simple wrapper for synchronous operations that complete immediately. The result is stored and returned on first call to finish(). Subsequent calls will return a clone of the original error (if the operation failed) or an AlreadyFinished error (if the operation succeeded).

Implementations

Source

impl<T, E: Clone> EagerOpRef<T, E>

pub fn ok(id: OpId, value: T) -> Self

pub fn err(id: OpId, error: E) -> Self